/*******************************************************************************
 * This file is part of OpenNMS(R).
 *
 * Copyright (C) 2016-2016 The OpenNMS Group, Inc.
 * OpenNMS(R) is Copyright (C) 1999-2016 The OpenNMS Group, Inc.
 *
 * OpenNMS(R) is a registered trademark of The OpenNMS Group, Inc.
 *
 * OpenNMS(R) is free software: you can redistribute it and/or modify
 * it under the terms of the GNU Affero General Public License as published
 * by the Free Software Foundation, either version 3 of the License,
 * or (at your option) any later version.
 *
 * OpenNMS(R) is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU Affero General Public License for more details.
 *
 * You should have received a copy of the GNU Affero General Public License
 * along with OpenNMS(R).  If not, see:
 *      http://www.gnu.org/licenses/
 *
 * For more information contact:
 *     OpenNMS(R) Licensing <license@opennms.org>
 *     http://www.opennms.org/
 *     http://www.opennms.com/
 *******************************************************************************/

package org.opennms.core.camel;

import org.apache.camel.component.netty4.DefaultChannelHandlerFactory;

import io.netty.channel.ChannelHandler;
import io.netty.handler.codec.xml.XmlFrameDecoder;

/**
 * This factory produces instances of the non-{@link Sharable}
 * {@link XmlFrameDecoder} handler.
 */
public class XmlFrameDecoderFactory extends DefaultChannelHandlerFactory {

	private final int m_maxFrameLength;

	public XmlFrameDecoderFactory() {
		this(Integer.MAX_VALUE);
	}

	public XmlFrameDecoderFactory(int maxFrameLength) {
		m_maxFrameLength = maxFrameLength;
	}

	@Override
	public ChannelHandler newChannelHandler() {
		return new XmlFrameDecoder(m_maxFrameLength);
	}
}
