/*******************************************************************************
 * This file is part of OpenNMS(R).
 *
 * Copyright (C) 2017-2017 The OpenNMS Group, Inc.
 * OpenNMS(R) is Copyright (C) 1999-2017 The OpenNMS Group, Inc.
 *
 * OpenNMS(R) is a registered trademark of The OpenNMS Group, Inc.
 *
 * OpenNMS(R) is free software: you can redistribute it and/or modify
 * it under the terms of the GNU Affero General Public License as published
 * by the Free Software Foundation, either version 3 of the License,
 * or (at your option) any later version.
 *
 * OpenNMS(R) is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU Affero General Public License for more details.
 *
 * You should have received a copy of the GNU Affero General Public License
 * along with OpenNMS(R).  If not, see:
 *      http://www.gnu.org/licenses/
 *
 * For more information contact:
 *     OpenNMS(R) Licensing <license@opennms.org>
 *     http://www.opennms.org/
 *     http://www.opennms.com/
 *******************************************************************************/

package org.opennms.features.jest.client.credentials;

import java.util.ArrayList;
import java.util.List;
import java.util.Objects;

import javax.xml.bind.annotation.XmlAccessType;
import javax.xml.bind.annotation.XmlAccessorType;
import javax.xml.bind.annotation.XmlElement;
import javax.xml.bind.annotation.XmlRootElement;

@XmlRootElement(name="elastic-credentials")
@XmlAccessorType(XmlAccessType.NONE)
public class ElasticCredentials {
    @XmlElement(name = "credentials")
    private List<CredentialsScope> credentialsScopes = new ArrayList<>();

    public List<CredentialsScope> getCredentialsScopes() {
        return credentialsScopes;
    }

    public void setCredentialsScopes(List<CredentialsScope> credentialsScopes) {
        this.credentialsScopes = credentialsScopes;
    }

    public ElasticCredentials withCredentials(CredentialsScope credentialsScope) {
        if (credentialsScope != null) {
            this.credentialsScopes.add(credentialsScope);
        }
        return this;
    }

    @Override
    public boolean equals(Object o) {
        if (this == o) return true;
        if (o == null) return false;
        if (o instanceof ElasticCredentials) {
            final ElasticCredentials that = (ElasticCredentials) o;
            return Objects.equals(credentialsScopes, that.credentialsScopes);
        }
        return false;
    }

    @Override
    public int hashCode() {
        return Objects.hash(credentialsScopes);
    }
}
