/*******************************************************************************
 * This file is part of OpenNMS(R).
 *
 * Copyright (C) 2022 The OpenNMS Group, Inc.
 * OpenNMS(R) is Copyright (C) 1999-2022 The OpenNMS Group, Inc.
 *
 * OpenNMS(R) is a registered trademark of The OpenNMS Group, Inc.
 *
 * OpenNMS(R) is free software: you can redistribute it and/or modify
 * it under the terms of the GNU Affero General Public License as published
 * by the Free Software Foundation, either version 3 of the License,
 * or (at your option) any later version.
 *
 * OpenNMS(R) is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU Affero General Public License for more details.
 *
 * You should have received a copy of the GNU Affero General Public License
 * along with OpenNMS(R).  If not, see:
 *      http://www.gnu.org/licenses/
 *
 * For more information contact:
 *     OpenNMS(R) Licensing <license@opennms.org>
 *     http://www.opennms.org/
 *     http://www.opennms.com/
 *******************************************************************************/

package org.opennms.features.scv.rest;

import java.util.HashMap;
import java.util.Map;
import java.util.Objects;
import java.util.StringJoiner;

public class CredentialsDTO {

    private String alias;

    private String username;
    private String password;
    private Map<String, String> attributes = new HashMap<>();

    public CredentialsDTO() {
    }

    public CredentialsDTO(String alias, String username, String password) {
        this.alias = alias;
        this.username = username;
        this.password = password;
    }

    public CredentialsDTO(String alias, String username, String password, Map<String, String> attributes) {
        this.alias = alias;
        this.username = username;
        this.password = password;
        this.attributes = attributes;
    }

    public String getAlias() {
        return alias;
    }

    public void setAlias(String alias) {
        this.alias = alias;
    }

    public String getUsername() {
        return username;
    }

    public void setUsername(String username) {
        this.username = username;
    }

    public String getPassword() {
        return password;
    }

    public void setPassword(String password) {
        this.password = password;
    }

    public Map<String, String> getAttributes() {
        return attributes;
    }

    public void setAttributes(Map<String, String> attributes) {
        this.attributes = attributes;
    }

    public void addAttributes(Map<String, String> attributes) {
        this.attributes.putAll(attributes);
    }
    
    @Override
    public boolean equals(Object o) {
        if (this == o) return true;
        if (!(o instanceof CredentialsDTO)) return false;
        CredentialsDTO dto = (CredentialsDTO) o;
        return Objects.equals(alias, dto.alias) && Objects.equals(username, dto.username) &&
                Objects.equals(password, dto.password) && Objects.equals(attributes, dto.attributes);
    }

    @Override
    public int hashCode() {
        return Objects.hash(alias, username, password, attributes);
    }

    @Override
    public String toString() {
        return String.format("Credentials[alias=%s, username=%s,password=XXXXXX]", alias, username);
    }
}
